@@ -161,16 +161,16 @@ char *csudsu_menu_te1_dm[]={
 "","-- T1/E1 (AFT T1/E1-DM) Stats --",
 ""," ",
 "Ta","Read T1/E1 alarms",
-"Taflb","E Framer Loopback T1/E1",
-"Tdflb","D Framer Loopback T1/E1",
-"Tafplb","E Payload Loopback T1/E1",
-"Tdfplb","D Payload Loopback T1/E1",
+"Tallb","E Line/Remote Loopback T1/E1",
+"Tdllb","D Line/Remote Loopback T1/E1",
+"Taplb","E Payload Loopback T1/E1",
+"Tdplb","D Payload Loopback T1/E1",
+"Tadlb","E Diag Digital Loopback T1/E1",
+"Tddlb","D Diag Digital Loopback T1/E1",
 "Talalb","E LIU Analog Loopback T1/E1",
 "Tdlalb","D LIU Analog Loopback T1/E1",
 "Talllb","E LIU Local Loopback T1/E1",
 "Tdlllb","D LIU Local Loopback T1/E1",
-"Talrlb","E LIU Remote Loopback T1/E1",
-"Tdlrlb","D LIU Remote Loopback T1/E1",
 "Taldlb","E LIU Dual Loopback T1/E1",
 "Tdldlb","D LIU Dual Loopback T1/E1",
 "Tsalb","Send Loopback Activate Code",  
@@ -927,16 +927,34 @@ static void hw_set_lb_modes(unsigned char type, unsigned char mode)
 	}
 #endif
 	DO_COMMAND(wan_udp);
-	printf("%s %s mode ... %s!\n",
-			WAN_TE1_LB_ACTION_DECODE(mode),
-			WAN_TE1_LB_MODE_DECODE(type),
-			(!wan_udp.wan_udphdr_return_code)?"Done":"Failed");
+	if (femedia.media == WAN_MEDIA_T1 || femedia.media == WAN_MEDIA_E1){
+		printf("%s %s mode ... %s!\n",
+				WAN_TE1_LB_ACTION_DECODE(mode),
+				WAN_TE1_LB_MODE_DECODE(type),
+				(!wan_udp.wan_udphdr_return_code)?"Done":"Failed");
+	}else if (femedia.media == WAN_MEDIA_DS3 || femedia.media == WAN_MEDIA_E3){
+		printf("%s %s mode ... %s!\n",
+				WAN_TE3_LB_ACTION_DECODE(mode),
+				WAN_TE3_LB_TYPE_DECODE(type),
+				(!wan_udp.wan_udphdr_return_code)?"Done":"Failed");
+	}else{
+		printf("%s %s mode ... %s (default)!\n",
+				WAN_TE1_LB_ACTION_DECODE(mode),
+				WAN_TE1_LB_MODE_DECODE(type),
+				(!wan_udp.wan_udphdr_return_code)?"Done":"Failed");
+	}
 	return;
 }
 
 void get_lb_modes()
 {
 
+	if ((femedia.media != WAN_MEDIA_T1) && (femedia.media != WAN_MEDIA_E1) &&
+	    (femedia.media != WAN_MEDIA_DS3) && (femedia.media != WAN_MEDIA_E3)){
+		printf("Error: Unsupported feature for current media type %02X!\n",
+						femedia.media);
+		return;
+	}
 	if(make_hardware_level_connection()){
 		return;
 	}
@@ -956,31 +974,42 @@ void get_lb_modes()
 			printf("All loopback mode are disabled!");
 		}else{
 			printf("***** %s: %s Loopback status *****\n\n",
-				if_name, (femedia.media == WAN_MEDIA_T1) ? "T1" : "E1");
-			if (mode & (1<<WAN_TE1_FR_FLB_MODE)){
-				printf("\tFramer Loopback:\tON\n");
-			}
-			if (mode & (1<<WAN_TE1_FR_PLB_MODE)){
-				printf("\tPayload Loopback:\tON\n");
-			}
+					if_name,
+					(femedia.media == WAN_MEDIA_T1)  ? "T1" :
+					(femedia.media == WAN_MEDIA_E1)  ? "E1" :
+					(femedia.media == WAN_MEDIA_DS3) ? "DS3" :
+					(femedia.media == WAN_MEDIA_E3)  ? "E3" : "Unknown");
+			if ((femedia.media == WAN_MEDIA_T1) || (femedia.media == WAN_MEDIA_E1)){
 			
-			if (mode & (1<<WAN_TE1_LIU_ALB_MODE)){
-				printf("\tLIU Analog Loopback:\tON\n");
-			}
-			if (mode & (1<<WAN_TE1_LIU_LLB_MODE)){
-				printf("\tLIU Local Loopback:\tON\n");
-			}
-			if (mode & (1<<WAN_TE1_LIU_RLB_MODE)){
-				printf("\tLIU Remote Loopback:\tON\n");
-			}
-			if (mode & (1<<WAN_TE1_LINELB_MODE)){
-				printf("\tLine Loopback:\t\tON\n");
-			}
-			if (mode & (1<<WAN_TE1_PAYLB_MODE)){
-				printf("\tPayload Loopback:\tON\n");
-			}
-			if (mode & (1<<WAN_TE1_DDLB_MODE)){
-				printf("\tDiagnostic Digital Loopback:\tON\n");
+				if (mode & (1<<WAN_TE1_LIU_ALB_MODE)){
+					printf("\tLIU Analog Loopback:\tON\n");
+				}
+				if (mode & (1<<WAN_TE1_LIU_LLB_MODE)){
+					printf("\tLIU Local Loopback:\tON\n");
+				}
+				if (mode & (1<<WAN_TE1_LIU_RLB_MODE)){
+					printf("\tLIU Remote Loopback:\tON\n");
+				}
+				if (mode & (1<<WAN_TE1_LINELB_MODE)){
+					printf("\tLine/Remote Loopback:\t\tON\n");
+				}
+				if (mode & (1<<WAN_TE1_PAYLB_MODE)){
+					printf("\tPayload Loopback:\tON\n");
+				}
+				if (mode & (1<<WAN_TE1_DDLB_MODE)){
+					printf("\tDiagnostic Digital Loopback:\tON\n");
+				}
+			}else{
+
+				if (mode & (1<<WAN_TE3_LIU_LB_DIGITAL)){
+					printf("\tDigital Loopback:\tON\n");
+				} 
+				if (mode & (1<<WAN_TE3_LIU_LB_REMOTE)){
+					printf("\tRemote Loopback:\tON\n");
+				}
+				if (mode & (1<<WAN_TE3_LIU_LB_ANALOG)){
+					printf("\tAnalog Loopback:\tON\n");
+				}
 			}
 		}	
 	}
